;________________________________________________________________________
;
;                          P I C E D I A G . A S M
;________________________________________________________________________
;
; Sample PIC16F84 code by Byon Garrabrant  N6BG  byon@mail.com  Feb 1999
;________________________________________________________________________

	LIST	P=PIC16F84
	include	"..\P16F84.INC"
	__CONFIG _HS_OSC & _CP_OFF & _PWRTE_ON & _WDT_OFF

;________________________________________________________________________

	cblock	H'0C'			; system variables
		delay1
		delay2
	endc
;________________________________________________________________________

#define	VALID_OUT	PORTB, 0
#define	MODE1_OUT	PORTB, 1
#define	MODE0_OUT	PORTB, 2
#define	TONE_IN		PORTB, 4
#define	OPTION_IN	PORTB, 4
#define	TONE_OUT	PORTB, 5

#define	PTT_OUT		PORTA, 2
#define	PTT_IN		PORTA, 3
#define	MODE_IN		PORTA, 4

;________________________________________________________________________

	ORG	0			; start code
	goto	main
;________________________________________________________________________

delay1200				; delay for about 833 us (2083 ins)
					; actuall 2066 w/o call/return
	movlw	D'177'
	movwf	delay1
	movlw	D'3'
	movwf	delay2
delayLoop	
	decfsz	delay1, F		; loop 256/177 times
	 goto	delayLoop
	decfsz	delay2, F		; loop 3 times
	 goto	delayLoop
	return 
;________________________________________________________________________

flash
	bsf	VALID_OUT		; turn VALID OUT ON
	call	flashDelay		; delay
	bcf	VALID_OUT		; turn VALID OUT OFF
	call	flashDelay		; delay
	return

flashDelay
	nop
	decfsz	delay1, F		; loop 256 times
	 goto	flashDelay
	decfsz	delay2, F		; loop 256 times
	 goto	flashDelay
	return 
;________________________________________________________________________

main
	bsf	STATUS, RP0		; Select Bank 1
	bcf	PTT_OUT			; make PTT an output
	bcf	TONE_OUT		; make data an output
	bcf	MODE0_OUT		; make mode0 an output
	bcf	MODE1_OUT		; make mode1 an output
	bcf	VALID_OUT		; make valid an output
	bcf	STATUS, RP0		; SelectBank 0

	bsf	MODE1_OUT		; disable audio tone
	bcf	MODE0_OUT		; disable audio tone
	bcf	PTT_OUT			; clear PTT_OUT

	call	flash			; flash valid 3 times
	call	flash
	call	flash

mainLoop
	btfsc	OPTION_IN		; if OPTION IN ON
	 bsf	VALID_OUT		;  turn VALID OUT ON
	btfss	OPTION_IN		; if OPTION IN OFF
	 bcf	VALID_OUT		;  turn VALID OUT OFF
	 
	btfss	MODE_IN			; if MODE IN OFF
	 goto	noTone			;  no tones
	 
	bcf	MODE1_OUT		; enable audio tone
	bsf	MODE0_OUT		; enable audio tone
	bsf	PTT_OUT			; enable PTT_OUT
	
	movlw	B'00100000'		; toggle tone_out
	xorwf	PORTB, F
	call	delay1200		; delay for about 1/1200 sec
	goto	mainLoop		; do it again
	
noTone	
	bsf	MODE1_OUT		; disable audio tone
	bcf	MODE0_OUT		; disable audio tone
	bcf	PTT_OUT			; clear PTT_OUT
	goto	mainLoop		; do it again
	 
	END
;________________________________________________________________________


